@@ -400,7 +400,7 @@ public :
 	Finder* getFinderFrom(HWND hwnd);
 
 protected :
-	void resizeDialogElements(LONG newWidth);
+	void resizeDialogElements();
 	intptr_t CALLBACK run_dlgProc(UINT message, WPARAM wParam, LPARAM lParam) override;
 	static WNDPROC originalFinderProc;
 	static WNDPROC originalComboEditProc;
@@ -412,10 +412,10 @@ protected :
 
 	void combo2ExtendedMode(int comboID);
 
-private :
-	RECT _initialWindowRect{};
-	LONG _deltaWidth = 0;
-	LONG _initialClientWidth = 0;
+private:
+	SIZE _szMinDialog{};
+	SIZE _szBorder{};
+
 	LONG _lesssModeHeight = 0;
 
 	DIALOG_TYPE _currentStatus = DIALOG_TYPE::FIND_DLG;
@@ -448,7 +448,7 @@ private :
 	HICON _statusbarTooltipIcon = nullptr;
 	int _statusbarTooltipIconSize = 0;
 
-	HFONT _hMonospaceFont = nullptr;
+	HFONT _hComboBoxFont = nullptr;
 	HFONT _hLargerBolderFont = nullptr;
 	HFONT _hCourrierNewFont = nullptr;
 
@@ -572,10 +572,7 @@ private:
 	static const TCHAR cClassName[];
 	static const TCHAR cDefaultHeader[];
 	static const int cBackgroundColor;
-	static const int cPBwidth;
-	static const int cPBheight;
-	static const int cBTNwidth;
-	static const int cBTNheight;
+	static const SIZE _szClient;
 
 	static volatile LONG refCount;
 
@@ -585,6 +582,10 @@ private:
 	int thread();
 	int createProgressWindow();
 
+	RECT getDpiScaledWindowRect(UINT dpi) const;
+	void setCtrlsPos();
+	void setFont();
+
 	HINSTANCE _hInst = nullptr;
 	volatile HWND _hwnd = nullptr;
 	HWND _hCallerWnd = nullptr;
@@ -597,4 +598,6 @@ private:
 	HWND _hPBar = nullptr;
 	HWND _hBtn = nullptr;
 	HFONT _hFont = nullptr;
+
+	DPIManagerV2 _dpiManager;
 };
