@@ -22,8 +22,8 @@
 
 #define DM_PANELTITLE     TEXT("Document Map")
 
-#define DOCUMENTMAP_SCROLL        (WM_USER + 1)
-#define DOCUMENTMAP_MOUSECLICKED  (WM_USER + 2)
+#define DOCUMENTMAP_SCROLL        (WM_USER + 4) // DM_SETDEFID uses WM_USER + 1
+#define DOCUMENTMAP_MOUSECLICKED  (WM_USER + 5) // DM_REPOSITION uses WM_USER + 2
 #define DOCUMENTMAP_MOUSEWHEEL    (WM_USER + 3)
 
 const TCHAR VIEWZONE_DOCUMENTMAP[64] = TEXT("Document map");
