@@ -19,6 +19,7 @@
 #include <memory>
 #include "ImageListSet.h"
 #include "NppDarkMode.h"
+#include "dpiManagerV2.h"
 
 void IconList::init(HINSTANCE hInst, int iconSize) 
 {
@@ -31,19 +32,22 @@ void IconList::init(HINSTANCE hInst, int iconSize)
 		throw std::runtime_error("IconList::create : ImageList_Create() function returns null");
 }
 
-void IconList::create(int iconSize, HINSTANCE hInst, int *iconIDArray, int iconIDArraySize)
+
+void IconList::create(int iconSize, HINSTANCE hInst, int* iconIDArray, int iconIDArraySize)
 {
 	init(hInst, iconSize);
 	_pIconIDArray = iconIDArray;
 	_iconIDArraySize = iconIDArraySize;
 
-	for (int i = 0 ; i < iconIDArraySize ; ++i)
-		addIcon(iconIDArray[i]);
+	for (int i = 0; i < iconIDArraySize; ++i)
+		addIcon(iconIDArray[i], iconSize, iconSize);
 }
 
-void IconList::addIcon(int iconID) const 
+void IconList::addIcon(int iconID, int cx, int cy) const
 {
-	HICON hIcon = ::LoadIcon(_hInst, MAKEINTRESOURCE(iconID));
+	HICON hIcon = nullptr;
+	DPIManagerV2::loadIcon(_hInst, MAKEINTRESOURCE(iconID), cx, cy, &hIcon, LR_DEFAULTSIZE);
+
 	if (!hIcon)
 		throw std::runtime_error("IconList::addIcon : LoadIcon() function return null");
 
@@ -68,7 +72,7 @@ bool IconList::changeIcon(size_t index, const TCHAR *iconLocation) const
 	return (i == index);
 }
 
-void ToolBarIcons::init(ToolBarButtonUnit *buttonUnitArray, int arraySize, std::vector<DynamicCmdIcoBmp> moreCmds)
+void ToolBarIcons::init(ToolBarButtonUnit *buttonUnitArray, int arraySize, const std::vector<DynamicCmdIcoBmp>& moreCmds)
 {
 	for (int i = 0 ; i < arraySize ; ++i)
 		_tbiis.push_back(buttonUnitArray[i]);
@@ -99,15 +103,15 @@ void ToolBarIcons::reInit(int size)
 	{
 		if (_tbiis[i]._defaultIcon != -1)
 		{
-			_iconListVector[HLIST_DEFAULT].addIcon(_tbiis[i]._defaultIcon);
-			_iconListVector[HLIST_DISABLE].addIcon(_tbiis[i]._grayIcon);
-			_iconListVector[HLIST_DEFAULT2].addIcon(_tbiis[i]._defaultIcon2);
-			_iconListVector[HLIST_DISABLE2].addIcon(_tbiis[i]._grayIcon2);
+			_iconListVector[HLIST_DEFAULT].addIcon(_tbiis[i]._defaultIcon, size, size);
+			_iconListVector[HLIST_DISABLE].addIcon(_tbiis[i]._grayIcon, size, size);
+			_iconListVector[HLIST_DEFAULT2].addIcon(_tbiis[i]._defaultIcon2, size, size);
+			_iconListVector[HLIST_DISABLE2].addIcon(_tbiis[i]._grayIcon2, size, size);
 
-			_iconListVector[HLIST_DEFAULT_DM].addIcon(_tbiis[i]._defaultDarkModeIcon);
-			_iconListVector[HLIST_DISABLE_DM].addIcon(_tbiis[i]._grayDarkModeIcon);
-			_iconListVector[HLIST_DEFAULT_DM2].addIcon(_tbiis[i]._defaultDarkModeIcon2);
-			_iconListVector[HLIST_DISABLE_DM2].addIcon(_tbiis[i]._grayDarkModeIcon2);
+			_iconListVector[HLIST_DEFAULT_DM].addIcon(_tbiis[i]._defaultDarkModeIcon, size, size);
+			_iconListVector[HLIST_DISABLE_DM].addIcon(_tbiis[i]._grayDarkModeIcon, size, size);
+			_iconListVector[HLIST_DEFAULT_DM2].addIcon(_tbiis[i]._defaultDarkModeIcon2, size, size);
+			_iconListVector[HLIST_DISABLE_DM2].addIcon(_tbiis[i]._grayDarkModeIcon2, size, size);
 		}
 	}
 
