@@ -211,15 +211,15 @@
 
 #define	IDD_PREFERENCE_SUB_MISC 6300 //(IDD_PREFERENCE_BOX + 300)
 	#define	IDC_TABSETTING_GB_STATIC (IDD_PREFERENCE_SUB_MISC + 1)
-	#define	IDC_CHECK_REPLACEBYSPACE (IDD_PREFERENCE_SUB_MISC + 2)
+	#define	IDC_RADIO_REPLACEBYSPACE (IDD_PREFERENCE_SUB_MISC + 2)
 	#define	IDC_TABSIZE_STATIC (IDD_PREFERENCE_SUB_MISC + 3)
 	#define	IDC_HISTORY_GB_STATIC (IDD_PREFERENCE_SUB_MISC + 4)
 	#define	IDC_CHECK_DONTCHECKHISTORY (IDD_PREFERENCE_SUB_MISC + 5)
 	#define	IDC_MAXNBFILE_STATIC (IDD_PREFERENCE_SUB_MISC + 6)
 	#define	IDC_CHECK_MIN2SYSTRAY (IDD_PREFERENCE_SUB_MISC + 8)
 	#define	IDC_CHECK_REMEMBERSESSION (IDD_PREFERENCE_SUB_MISC + 9)
-	//#define	IDC_TABSIZEVAL_STATIC (IDD_PREFERENCE_SUB_MISC + 10)
-	//#define	IDC_MAXNBFILEVAL_STATIC (IDD_PREFERENCE_SUB_MISC + 11)
+	#define	IDC_INDENTUSING_STATIC (IDD_PREFERENCE_SUB_MISC + 10)
+	#define	IDC_RADIO_USINGTAB (IDD_PREFERENCE_SUB_MISC + 11)
 	#define	IDC_FILEAUTODETECTION_STATIC (IDD_PREFERENCE_SUB_MISC + 12)
 	#define	IDC_CHECK_UPDATESILENTLY (IDD_PREFERENCE_SUB_MISC + 13)
 	#define	IDC_RADIO_BKNONE (IDD_PREFERENCE_SUB_MISC + 15)
@@ -319,7 +319,7 @@
 	#define	IDC_LIST_TABSETTNG (IDD_PREFERENCE_SUB_LANGUAGE + 9)
 	#define	IDC_CHECK_DEFAULTTABVALUE (IDD_PREFERENCE_SUB_LANGUAGE + 10)
 	#define	IDC_GR_TABVALUE_STATIC (IDD_PREFERENCE_SUB_LANGUAGE + 11)
-	//#define	IDC_TABSIZEVAL_DISABLE_STATIC (IDD_PREFERENCE_SUB_LANGUAGE + 12)
+	#define	IDC_CHECK_BACKSPACEUNINDENT (IDD_PREFERENCE_SUB_LANGUAGE + 12)
 	#define	IDC_EDIT_TABSIZEVAL (IDD_PREFERENCE_SUB_LANGUAGE + 13)
 
 #define	IDD_PREFERENCE_SUB_EDITING2 6520 //(IDD_PREFERENCE_BOX + 520)
