@@ -20,12 +20,13 @@
 #include "EncodingMapper.h"
 #include "localization.h"
 #include "fileBrowser.h"
+#include "NppDarkMode.h"
 
 using namespace std;
 
 
 
-MenuPosition menuPos[] = {
+MenuPosition g_menuFolderPositions[] = {
 //==============================================
 //	{L0,  L1, L2, id},
 //==============================================
@@ -110,6 +111,18 @@ MenuPosition menuPos[] = {
 	{ -1,  -1, -1, "" } // End of array
 };
 
+MenuPosition& getMenuPosition(const char* id)
+{
+	int nbSubMenuPos = sizeof(g_menuFolderPositions) / sizeof(MenuPosition);
+
+	for (int i = 0; i < nbSubMenuPos; ++i)
+	{
+		if (strcmp(g_menuFolderPositions[i]._id, id) == 0)
+			return g_menuFolderPositions[i];
+	}
+	return g_menuFolderPositions[nbSubMenuPos - 1];
+}
+
 void NativeLangSpeaker::init(TiXmlDocumentA *nativeLangDocRootA, bool loadIfEnglish)
 {
 	if (nativeLangDocRootA)
@@ -158,7 +171,7 @@ void NativeLangSpeaker::init(TiXmlDocumentA *nativeLangDocRootA, bool loadIfEngl
 				if (declaration)
 				{
 					const char * encodingStr = declaration->Encoding();
-					EncodingMapper& em = EncodingMapper::getInstance();
+					const EncodingMapper& em = EncodingMapper::getInstance();
                     int enc = em.getEncodingFromString(encodingStr);
                     _nativeLangEncoding = (enc != -1)?enc:CP_ACP;
 				}
@@ -336,20 +349,6 @@ generic_string NativeLangSpeaker::getLocalizedStrFromID(const char *strID, const
 }
 
 
-
-MenuPosition & getMenuPosition(const char *id)
-{
-
-	int nbSubMenuPos = sizeof(menuPos)/sizeof(MenuPosition);
-
-	for (int i = 0; i < nbSubMenuPos; ++i) 
-	{
-		if (strcmp(menuPos[i]._id, id) == 0)
-			return menuPos[i];
-	}
-	return menuPos[nbSubMenuPos-1];
-}
-
 // Get string from map.
 // If string not found, get string from menu, then put it into map for the next use.
 void NativeLangSpeaker::getMainMenuEntryName(std::wstring& dest, HMENU hMenu, const char* menuId, const wchar_t* defaultDest)
@@ -680,6 +679,7 @@ void NativeLangSpeaker::changeConfigLang(HWND hDlg)
 			{
 				const wchar_t *nameW = wmc.char2wchar(name, _nativeLangEncoding);
 				::SetWindowText(hItem, nameW);
+				resizeCheckboxRadioBtn(hItem);
 			}
 		}
 	}
@@ -743,7 +743,7 @@ void NativeLangSpeaker::changeUserDefineLangPopupDlg(HWND hDlg)
 			{
 				const wchar_t *nameW = wmc.char2wchar(name, _nativeLangEncoding);
 				::SetWindowText(hItem, nameW);
-
+				resizeCheckboxRadioBtn(hItem);
 			}
 		}
 	}
@@ -789,8 +789,8 @@ void NativeLangSpeaker::changeUserDefineLang(UserDefineDialog *userDefineDlg)
 				{
 					if (id == IDC_DOCK_BUTTON && userDefineDlg->isDocked())
 					{
-						generic_string name = getAttrNameByIdStr(TEXT("Undock"), userDefineDlgNode, std::to_string(IDC_UNDOCK_BUTTON).c_str());
-						::SetWindowText(hItem, name.c_str());
+						generic_string undockStr = getAttrNameByIdStr(TEXT("Undock"), userDefineDlgNode, std::to_string(IDC_UNDOCK_BUTTON).c_str());
+						::SetWindowText(hItem, undockStr.c_str());
 					}
 					else
 					{
@@ -838,6 +838,7 @@ void NativeLangSpeaker::changeUserDefineLang(UserDefineDialog *userDefineDlg)
 					{
 						const wchar_t *nameW = wmc.char2wchar(name, _nativeLangEncoding);
 						::SetWindowText(hItem, nameW);
+						resizeCheckboxRadioBtn(hItem);
 					}
 				}
 			}
@@ -1310,6 +1311,7 @@ bool NativeLangSpeaker::changeDlgLang(HWND hDlg, const char *dlgTagName, char *t
 			{
 				const wchar_t *nameW = wmc.char2wchar(name, _nativeLangEncoding);
 				::SetWindowText(hItem, nameW);
+				resizeCheckboxRadioBtn(hItem);
 			}
 		}
 	}
@@ -1529,3 +1531,33 @@ int NativeLangSpeaker::messageBox(const char *msgBoxTagName, HWND hWnd, const TC
 	}
 	return ::MessageBox(hWnd, msg.c_str(), title.c_str(), msgBoxType);
 }
+
+// Default English localization during Notepad++ launch
+// is handled in NppDarkMode::subclassButtonControl.
+void NativeLangSpeaker::resizeCheckboxRadioBtn(HWND hWnd)
+{
+	constexpr size_t classNameLen = 32;
+	wchar_t className[classNameLen]{};
+	::GetClassNameW(hWnd, className, classNameLen);
+	if (wcscmp(className, WC_BUTTON) == 0)
+	{
+		const auto nBtnStyle = ::GetWindowLongPtrW(hWnd, GWL_STYLE);
+		switch (nBtnStyle & BS_TYPEMASK)
+		{
+			case BS_CHECKBOX:
+			case BS_AUTOCHECKBOX:
+			case BS_RADIOBUTTON:
+			case BS_AUTORADIOBUTTON:
+			{
+				if ((nBtnStyle & BS_MULTILINE) != BS_MULTILINE)
+				{
+					::SendMessageW(hWnd, NppDarkMode::WM_SETBUTTONIDEALSIZE, 0, 0);
+				}
+				break;
+			}
+
+			default:
+				break;
+		}
+	}
+}
