@@ -559,6 +559,8 @@
     #define    IDM_LANG_MSSQL              (IDM_LANG + 86)
     #define    IDM_LANG_GDSCRIPT           (IDM_LANG + 87)
     #define    IDM_LANG_HOLLYWOOD          (IDM_LANG + 88)
+    #define    IDM_LANG_GOLANG             (IDM_LANG + 89)
+    #define    IDM_LANG_RAKU               (IDM_LANG + 90)
     
     #define    IDM_LANG_EXTERNAL           (IDM_LANG + 165)
     #define    IDM_LANG_EXTERNAL_LIMIT     (IDM_LANG + 179)
